@@ -94,7 +94,7 @@ floatingLegFrequency = Semiannual
 floatingLegTenor = Period(6,Months)
 floatingLegAdjustment = ModifiedFollowing
 swapHelpers = [ SwapRateHelper(QuoteHandle(swaps[(n,unit)]),
-                               Period(n,unit), settlementDays, calendar,
+                               Period(n,unit), calendar,
                                fixedLegFrequency, fixedLegAdjustment,
                                fixedLegDayCounter, Euribor6M())
                 for n, unit in swaps.keys() ]
@@ -115,6 +115,8 @@ depoFraSwapCurve = PiecewiseFlatForward(settlementDate, helpers, Actual360())
 
 # swaps to be priced
 
+swapEngine = DiscountingSwapEngine(discountTermStructure)
+
 nominal = 1000000
 length = 5
 maturity = calendar.advance(settlementDate,length,Years)
@@ -135,32 +137,34 @@ floatingLegDayCounter = index.dayCounter()
 fixedSchedule = Schedule(settlementDate, maturity,
                          fixedLegTenor, calendar,
                          fixedLegAdjustment, fixedLegAdjustment,
-                         False, False)
+                         DateGeneration.Forward, False)
 floatingSchedule = Schedule(settlementDate, maturity,
                             floatingLegTenor, calendar,
                             floatingLegAdjustment, floatingLegAdjustment,
-                            False, False)
+                            DateGeneration.Forward, False)
 
 spot = VanillaSwap(VanillaSwap.Payer, nominal,
                    fixedSchedule, fixedRate, fixedLegDayCounter,
                    floatingSchedule, index, spread,
-                   floatingLegDayCounter, discountTermStructure)
+                   floatingLegDayCounter)
+spot.setPricingEngine(swapEngine)
 
 forwardStart = calendar.advance(settlementDate,1,Years)
 forwardEnd = calendar.advance(forwardStart,length,Years)
 fixedSchedule = Schedule(forwardStart, forwardEnd,
                          fixedLegTenor, calendar,
                          fixedLegAdjustment, fixedLegAdjustment,
-                         False, False)
+                         DateGeneration.Forward, False)
 floatingSchedule = Schedule(forwardStart, forwardEnd,
                             floatingLegTenor, calendar,
                             floatingLegAdjustment, floatingLegAdjustment,
-                            False, False)
+                            DateGeneration.Forward, False)
 
 forward = VanillaSwap(VanillaSwap.Payer, nominal,
                       fixedSchedule, fixedRate, fixedLegDayCounter,
                       floatingSchedule, index, spread,
-                      floatingLegDayCounter, discountTermStructure)
+                      floatingLegDayCounter)
+forward.setPricingEngine(swapEngine)
 
 # price on the bootstrapped curves
 
