@@ -19,10 +19,14 @@
 
 import os, sys, string
 from distutils.cmd import Command
+from distutils.command.build_ext import build_ext
+from distutils.command.build import build
 from distutils.command.install_data import install_data
 from distutils.command.install import install
 from distutils.file_util import copy_file
+from distutils.ccompiler import get_default_compiler
 from distutils.core import setup, Extension
+from distutils import sysconfig
 
 class test(Command):
     # Original version of this class posted
@@ -44,7 +48,6 @@ class test(Command):
         self.build_platlib = build.build_platlib
 
     def run(self):
-        import sys
         # Testing depends on the module having been built
         self.run_command('build')
 
@@ -63,6 +66,7 @@ class test(Command):
 
 class my_wrap(Command):
     description = "generate Python wrappers"
+    user_options = []
     def initialize_options(self): pass
     def finalize_options(self): pass
     def run(self):
@@ -73,72 +77,110 @@ class my_wrap(Command):
                   '-outdir QuantLib -o QuantLib/quantlib_wrap.cpp ' +
                   'quantlib.i')
 
+class my_build(build):
+    user_options = build.user_options + [
+        ('dll', None,
+         "link against CRTDLL libraries on Windows")
+    ]
+    boolean_options = build.boolean_options + ['dll']
+    def initialize_options(self):
+        build.initialize_options(self)
+        self.dll = None
+    def finalize_options(self):
+        build.finalize_options(self)
 
-if sys.platform == 'win32':
-    try:
-        QL_INSTALL_DIR = os.environ['QL_DIR']
-        include_dirs = [QL_INSTALL_DIR]
-        library_dirs = [os.path.join(QL_INSTALL_DIR, 'lib')]
-    except KeyError, e:
-        print 'warning: unable to detect QuantLib installation'
-        print 'I will assume that it was added to the default compiler paths'
-        include_dirs = []
-        library_dirs = []
-    libraries = None
 
-    if '--compiler=bcpp' in sys.argv:
-        extra_compile_args = ['-vi-','-w-8057']
-        define_macros = [('__WIN32__', None), ('MSC_CORE_BC_EXT', None)]
-        extra_link_args = None
-    else:
-        extra_compile_args = ['/GR', '/FD', '/Zm250']
-        define_macros = [('__WIN32__', None), ('WIN32', None),
-                         ('NDEBUG', None), ('_WINDOWS', None),
-                         ('NOMINMAX', None)]
-        extra_link_args = ['/subsystem:windows',
-                           '/machine:I386']
+class my_build_ext(build_ext):
+    user_options = build_ext.user_options + [
+        ('dll', None,
+         "link against CRTDLL libraries on Windows")
+    ]
+    boolean_options = build.boolean_options + ['dll']
+    def initialize_options(self):
+        build_ext.initialize_options(self)
+        self.dll = None
+    def finalize_options(self):
+        build_ext.finalize_options(self)
+        self.set_undefined_options('build', ('dll','dll'))
 
-        if "--dll" in sys.argv:
-            use_dll = 1
-            for i in range(len(sys.argv)):
-                if sys.argv[i] == "--dll":
-                    del sys.argv[i]
-                    break
-        else:
-            use_dll = 0
+        self.include_dirs = self.include_dirs or []
+        self.library_dirs = self.library_dirs or []
+        self.define = self.define or []
+        self.libraries = self.libraries or []
 
-        if '--debug' in sys.argv:
-            if use_dll:
-                extra_compile_args.append('/MDd')
+        extra_compile_args = []
+        extra_link_args = []
+
+        compiler = self.compiler or get_default_compiler()
+
+        if compiler == 'msvc':
+            try:
+                QL_INSTALL_DIR = os.environ['QL_DIR']
+                self.include_dirs += [QL_INSTALL_DIR]
+                self.library_dirs += [os.path.join(QL_INSTALL_DIR, 'lib')]
+            except KeyError, e:
+                print 'warning: unable to detect QuantLib installation'
+
+            if os.environ.has_key('INCLUDE'):
+                dirs = [dir for dir in os.environ['INCLUDE'].split(';')]
+                self.include_dirs += dirs
+            if os.environ.has_key('LIB'):
+                dirs = [dir for dir in os.environ['LIB'].split(';')]
+                self.library_dirs += dirs
+
+            self.define += [('__WIN32__', None), ('WIN32', None),
+                            ('NDEBUG', None), ('_WINDOWS', None),
+                            ('NOMINMAX', None)]
+            extra_compile_args = ['/GR', '/FD', '/Zm250']
+            extra_link_args = ['/subsystem:windows', '/machine:I386']
+
+            if self.debug:
+                if self.dll:
+                    extra_compile_args.append('/MDd')
+                else:
+                    extra_compile_args.append('/MTd')
             else:
-                extra_compile_args.append('/MTd')
-        else:
-            if use_dll:
-                extra_compile_args.append('/MD')
-            else:
-                extra_compile_args.append('/MT')
+                if self.dll:
+                    extra_compile_args.append('/MD')
+                else:
+                    extra_compile_args.append('/MT')
 
-else:
-    from distutils import sysconfig
-    ql_compile_args = os.popen('quantlib-config --cflags').read()[:-1].split()
-    ql_link_args = os.popen('quantlib-config --libs').read()[:-1].split()
-    define_macros = [ (arg[2:],None) for arg in ql_compile_args
-                                     if arg.startswith('-D') ]
-    include_dirs = [ arg[2:] for arg in ql_compile_args
-                             if arg.startswith('-I') ]
-    library_dirs = [ arg[2:] for arg in ql_link_args
-                             if arg.startswith('-L') ]
-    libraries = [ arg[2:] for arg in ql_link_args
-                          if arg.startswith('-l') ]
-    extra_compile_args = [ arg for arg in ql_compile_args
-                               if not arg.startswith('-D')
-                               if not arg.startswith('-I') ] \
-                       + [ '-Wno-unused' ]
-    if os.environ.has_key('CXXFLAGS'):
-        extra_compile_args.extend(string.split(os.environ['CXXFLAGS']))
-    extra_link_args = [ arg for arg in ql_link_args
-                            if not arg.startswith('-L')
-                            if not arg.startswith('-l') ]
+        elif compiler == 'unix':
+            ql_compile_args = \
+                os.popen('quantlib-config --cflags').read()[:-1].split()
+            ql_link_args = \
+                os.popen('quantlib-config --libs').read()[:-1].split()
+            self.define += [ (arg[2:],None) for arg in ql_compile_args
+                             if arg.startswith('-D') ]
+            self.include_dirs += [ arg[2:] for arg in ql_compile_args
+                                   if arg.startswith('-I') ]
+            self.library_dirs += [ arg[2:] for arg in ql_link_args
+                                   if arg.startswith('-L') ]
+            self.libraries += [ arg[2:] for arg in ql_link_args
+                                if arg.startswith('-l') ]
+
+            extra_compile_args = [ arg for arg in ql_compile_args
+                                   if not arg.startswith('-D')
+                                   if not arg.startswith('-I') ] \
+                                   + [ '-Wno-unused' ]
+            if os.environ.has_key('CXXFLAGS'):
+                extra_compile_args += string.split(os.environ['CXXFLAGS'])
+
+            extra_link_args = [ arg for arg in ql_link_args
+                                if not arg.startswith('-L')
+                                if not arg.startswith('-l') ]
+
+        else:
+            pass
+
+        for ext in self.extensions:
+            ext.extra_compile_args = ext.extra_compile_args or []
+            ext.extra_compile_args += extra_compile_args
+
+            ext.extra_link_args = ext.extra_link_args or []
+            ext.extra_link_args += extra_link_args
+
+if os.name == 'posix':
     # changes the compiler from gcc to g++
     save_init_posix = sysconfig._init_posix
     def my_init_posix():
@@ -177,7 +219,7 @@ classifiers = [
 ]
 
 setup(name             = "QuantLib-Python",
-      version          = "0.8.0",
+      version          = "0.9.0",
       description      = "Python bindings for the QuantLib library",
       long_description = """
 QuantLib (http://quantlib.org/) is a C++ library for financial quantitative
@@ -191,15 +233,13 @@ framework for quantitative finance.
       classifiers      = classifiers,
       py_modules       = ['QuantLib.__init__','QuantLib.QuantLib'],
       ext_modules      = [Extension("QuantLib._QuantLib",
-                                    ["QuantLib/quantlib_wrap.cpp"],
-                                    libraries = libraries,
-                                    define_macros = define_macros,
-                                    include_dirs = include_dirs,
-                                    library_dirs = library_dirs,
-                                    extra_compile_args = extra_compile_args,
-                                    extra_link_args = extra_link_args)
+                                    ["QuantLib/quantlib_wrap.cpp"])
                          ],
       data_files       = datafiles,
       cmdclass         = {'test': test,
-                          'wrap': my_wrap}
+                          'wrap': my_wrap,
+                          'build': my_build,
+                          'build_ext': my_build_ext
+                          }
       )
+
