@@ -14,10 +14,10 @@ dividendYield <- FlatForward(settlementDate, 0.05, Actual365Fixed())
 underlying <- SimpleQuote(10.0)
 engine <- AnalyticEuropeanEngine()
 volatilityQuote <- SimpleQuote(0.05)
-volatility <- BlackConstantVol(todaysDate,
+volatility <- BlackConstantVol(todaysDate, TARGET(), 
 	   QuoteHandle(volatilityQuote), 
 	      Actual365Fixed())
-process <- BlackScholesProcess(QuoteHandle(underlying),
+process <- BlackScholesMertonProcess(QuoteHandle(underlying),
 		YieldTermStructureHandle(dividendYield),
 		YieldTermStructureHandle(riskFreeRate),
 		BlackVolTermStructureHandle(volatility))
